@@ -26,6 +26,7 @@
 #define         Ack             0x02
 #define         Nak             0x03
 #define         NoRoute		0x04
+#define		RepActive	0x80
 #define         ReqEnd          0xff
 
 
@@ -51,14 +52,23 @@ struct  shm_form {
                                         /* 0x01 リクエスト　    */
                                         /* 0x02 リプライ        */
                                         /* 0x03 未登録          */
-                                        /* 0x04 ポート登録      */
+					/* 0x04 転送先無し	*/
                                         /* 0xff 削除            */
-        char    protocol;
-        char    dstRep[8];
-        char    Rep2Call[8];
-        char    Rep1Call[8];
-        char    dstCall[8];
-        char    srcCall[8];
+	char		protocol;
+	union {
+		struct {
+        		char    dstRep[8];
+        		char    Rep2Call[8];
+        		char    Rep1Call[8];
+        		char    dstCall[8];
+        		char    srcCall[8];
+		};
+		struct {
+			char	rep_name[8];
+			char	trust_name[16];
+			char	reserve[16];
+		};
+	};
         in_port_t       srcPort;
         struct  in_addr srcIP;
 	unsigned char	PackerID[2];
